* @param aReporter A sink for error messages. Use NULL_REPORTER if you don't need errors.
@@ -348,10 +302,10 @@ public:
int CheckAnnotation( REPORTER& aReporter );
/**
- * Function sortByXCoordinate
+ * Function SortByXCoordinate
* sorts the list of references by X position.
*
- * Components are sorted as follows:
+ * Symbols are sorted as follows:
*
*
Numeric value of reference designator.
*
Sheet number.
@@ -367,10 +321,10 @@ public:
}
/**
- * Function sortByYCoordinate
+ * Function SortByYCoordinate
* sorts the list of references by Y position.
*
- * Components are sorted as follows:
+ * Symbols are sorted as follows:
*
*
Numeric value of reference designator.
*
Sheet number.
@@ -386,7 +340,7 @@ public:
}
/**
- * Function SortComponentsByTimeStamp
+ * Function SortByTimeStamp
* sort the flat list by Time Stamp (sheet path + timestamp).
* Useful to detect duplicate Time Stamps
*/
@@ -399,11 +353,11 @@ public:
* Function SortByRefAndValue
* sorts the list of references by value.
*
- * Components are sorted in the following order:
+ * Symbols are sorted in the following order:
*
*
Numeric value of reference designator.
- *
Value of component.
- *
Unit number when component has multiple parts.
+ *
Value of symbol.
+ *
Unit number when symbol has multiple parts.
*
Sheet number.
*
X coordinate position.
*
Y coordinate position.
@@ -419,10 +373,10 @@ public:
* Function SortByReferenceOnly
* sorts the list of references by reference.
*
- * Components are sorted in the following order:
+ * Symbols are sorted in the following order:
*
*
Numeric value of reference designator.
- *
Unit number when component has multiple parts.
+ *
Unit number when symbol has multiple parts.
*
*
*/
@@ -432,26 +386,25 @@ public:
}
/**
- * searches the list for a component with a given reference.
+ * searches the list for a symbol with a given reference.
* @param aPath
* @return
*/
int FindRef( const wxString& aPath ) const;
/**
- * searches the sorted list of components for a another component with the same
- * reference and a given part unit. Use this method to manage components with
- * multiple parts per package.
- * @param aIndex = index in aComponentsList for of given SCH_REFERENCE item to test.
+ * searches the sorted list of symbols for a another symbol with the same reference and a
+ * given part unit. Use this method to manage symbols with multiple parts per package.
+ * @param aIndex = index in aSymbolsList for of given SCH_REFERENCE item to test.
* @param aUnit = the given unit number to search
- * @return index in aComponentsList if found or -1 if not found
+ * @return index in aSymbolsList if found or -1 if not found
*/
int FindUnit( size_t aIndex, int aUnit );
/**
- * searches the list for a component with the given KIID path
+ * searches the list for a symbol with the given KIID path
* @param aPath path to search
- * @return index in aComponentsList if found or -1 if not found
+ * @return index in aSymbolsList if found or -1 if not found
*/
int FindRefByPath( const wxString& aPath ) const;
@@ -459,7 +412,7 @@ public:
* Function GetRefsInUse
* adds all the reference designator numbers greater than \a aMinRefId to \a aIdList
* skipping the reference at \a aIndex.
- * @param aIndex = the current component index to use for reference prefix filtering.
+ * @param aIndex = the current symbol's index to use for reference prefix filtering.
* @param aIdList = the buffer to fill
* @param aMinRefId = the min id value to store. all values < aMinRefId are ignored
*/
@@ -467,9 +420,8 @@ public:
/**
* Function GetLastReference
- * returns the last used (greatest) reference number in the reference list
- * for the prefix reference given by \a aIndex. The component list must be
- * sorted.
+ * returns the last used (greatest) reference number in the reference list for the prefix
+ * used by the symbol pointed to by \a aIndex. The symbol list must be sorted.
*
* @param aIndex The index of the reference item used for the search pattern.
* @param aMinValue The minimum value for the current search.
@@ -486,11 +438,10 @@ public:
SCH_REFERENCE& schref = flatList[i];
printf( " [%-2d] ref:%-8s num:%-3d lib_part:%s\n",
- i,
- schref.m_Ref.c_str(),
- schref.m_NumRef,
- TO_UTF8( schref.GetLibPart()->GetName() )
- );
+ i,
+ schref.m_ref.c_str(),
+ schref.m_numRef,
+ TO_UTF8( schref.GetLibPart()->GetName() ) );
}
}
#endif
diff --git a/eeschema/sch_sheet_path.cpp b/eeschema/sch_sheet_path.cpp
index fcfba0ab3c..ead002f888 100644
--- a/eeschema/sch_sheet_path.cpp
+++ b/eeschema/sch_sheet_path.cpp
@@ -261,8 +261,8 @@ void SCH_SHEET_PATH::UpdateAllScreenReferences()
-void SCH_SHEET_PATH::GetComponents( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols,
- bool aForceIncludeOrphanComponents ) const
+void SCH_SHEET_PATH::GetSymbols( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols,
+ bool aForceIncludeOrphanComponents ) const
{
for( SCH_ITEM* item : LastScreen()->Items().OfType( SCH_COMPONENT_T ) )
{
@@ -693,16 +693,16 @@ void SCH_SHEET_LIST::AnnotatePowerSymbols()
}
-void SCH_SHEET_LIST::GetComponents( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols,
- bool aForceIncludeOrphanComponents ) const
+void SCH_SHEET_LIST::GetSymbols( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols,
+ bool aForceIncludeOrphanComponents ) const
{
for( const SCH_SHEET_PATH& sheet : *this )
- sheet.GetComponents( aReferences, aIncludePowerSymbols, aForceIncludeOrphanComponents );
+ sheet.GetSymbols( aReferences, aIncludePowerSymbols, aForceIncludeOrphanComponents );
}
-void SCH_SHEET_LIST::GetMultiUnitComponents( SCH_MULTI_UNIT_REFERENCE_MAP &aRefList,
- bool aIncludePowerSymbols ) const
+void SCH_SHEET_LIST::GetMultiUnitSymbols( SCH_MULTI_UNIT_REFERENCE_MAP &aRefList,
+ bool aIncludePowerSymbols ) const
{
for( SCH_SHEET_PATHS::const_iterator it = begin(); it != end(); ++it )
{
@@ -778,7 +778,7 @@ void SCH_SHEET_LIST::UpdateSymbolInstances(
{
SCH_REFERENCE_LIST symbolInstances;
- GetComponents( symbolInstances, true, true );
+ GetSymbols( symbolInstances, true, true );
std::map pathNameCache;
@@ -811,7 +811,7 @@ void SCH_SHEET_LIST::UpdateSymbolInstances(
continue;
}
- SCH_COMPONENT* symbol = symbolInstances[i].GetComp();
+ SCH_COMPONENT* symbol = symbolInstances[ i ].GetSymbol();
wxCHECK2( symbol, continue );
diff --git a/eeschema/sch_sheet_path.h b/eeschema/sch_sheet_path.h
index 263459215e..2d3347800c 100644
--- a/eeschema/sch_sheet_path.h
+++ b/eeschema/sch_sheet_path.h
@@ -293,8 +293,8 @@ public:
* ( orphan components)
* The normal option is false, and set to true only to build the full list of components.
*/
- void GetComponents( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols = true,
- bool aForceIncludeOrphanComponents = false ) const;
+ void GetSymbols( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols = true,
+ bool aForceIncludeOrphanComponents = false ) const;
/**
* Add a #SCH_REFERENCE_LIST object to \a aRefList for each same-reference set of
@@ -408,8 +408,8 @@ public:
* ( orphan components)
* The normal option is false, and set to true only to build the full list of components.
*/
- void GetComponents( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols = true,
- bool aForceIncludeOrphanComponents = false ) const;
+ void GetSymbols( SCH_REFERENCE_LIST& aReferences, bool aIncludePowerSymbols = true,
+ bool aForceIncludeOrphanComponents = false ) const;
/**
* Add a #SCH_REFERENCE_LIST object to \a aRefList for each same-reference set of
@@ -419,8 +419,8 @@ public:
* @param aRefList Map of reference designators to reference lists
* @param aIncludePowerSymbols Set to false to only get normal components.
*/
- void GetMultiUnitComponents( SCH_MULTI_UNIT_REFERENCE_MAP &aRefList,
- bool aIncludePowerSymbols = true ) const;
+ void GetMultiUnitSymbols( SCH_MULTI_UNIT_REFERENCE_MAP &aRefList,
+ bool aIncludePowerSymbols = true ) const;
/**
* Test every #SCH_SHEET_PATH in this #SCH_SHEET_LIST to verify if adding the sheets stored
diff --git a/eeschema/schematic.cpp b/eeschema/schematic.cpp
index a286291290..1540aa3828 100644
--- a/eeschema/schematic.cpp
+++ b/eeschema/schematic.cpp
@@ -230,18 +230,18 @@ wxString SCHEMATIC::ConvertRefsToKIIDs( const wxString& aSource ) const
wxString ref = token.BeforeFirst( ':', &remainder );
SCH_REFERENCE_LIST references;
- sheetList.GetComponents( references );
+ sheetList.GetSymbols( references );
for( size_t jj = 0; jj < references.GetCount(); jj++ )
{
- SCH_COMPONENT* refComponent = references[ jj ].GetComp();
+ SCH_COMPONENT* refSymbol = references[ jj ].GetSymbol();
- if( ref == refComponent->GetRef( &references[ jj ].GetSheetPath(), true ) )
+ if( ref == refSymbol->GetRef( &references[ jj ].GetSheetPath(), true ) )
{
wxString test( remainder );
- if( refComponent->ResolveTextVar( &test ) )
- token = refComponent->m_Uuid.AsString() + ":" + remainder;
+ if( refSymbol->ResolveTextVar( &test ) )
+ token = refSymbol->m_Uuid.AsString() + ":" + remainder;
break;
}
diff --git a/eeschema/symbol_editor/symbol_edit_frame.cpp b/eeschema/symbol_editor/symbol_edit_frame.cpp
index d80b211648..64905030d5 100644
--- a/eeschema/symbol_editor/symbol_edit_frame.cpp
+++ b/eeschema/symbol_editor/symbol_edit_frame.cpp
@@ -141,7 +141,7 @@ SYMBOL_EDIT_FRAME::SYMBOL_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
InitExitKey();
updateTitle();
- DisplayCmpDoc();
+ DisplaySymbolDatasheet();
RebuildSymbolUnitsList();
// Create the infobar
@@ -1252,6 +1252,6 @@ void SYMBOL_EDIT_FRAME::LoadSymbolFromSchematic( const std::unique_ptr
updateTitle();
RebuildSymbolUnitsList();
SetShowDeMorgan( GetCurPart()->HasConversion() );
- DisplayCmpDoc();
+ DisplaySymbolDatasheet();
Refresh();
}
diff --git a/eeschema/symbol_editor/symbol_editor.cpp b/eeschema/symbol_editor/symbol_editor.cpp
index 6a957f89e9..370528d6af 100644
--- a/eeschema/symbol_editor/symbol_editor.cpp
+++ b/eeschema/symbol_editor/symbol_editor.cpp
@@ -148,7 +148,7 @@ bool SYMBOL_EDIT_FRAME::saveCurrentPart()
}
-bool SYMBOL_EDIT_FRAME::LoadComponentAndSelectLib( const LIB_ID& aLibId, int aUnit, int aConvert )
+bool SYMBOL_EDIT_FRAME::LoadSymbolAndSelectLib( const LIB_ID& aLibId, int aUnit, int aConvert )
{
if( GetCurPart() && GetCurPart()->GetLibId() == aLibId
&& GetUnit() == aUnit && GetConvert() == aConvert )
@@ -167,12 +167,12 @@ bool SYMBOL_EDIT_FRAME::LoadComponentAndSelectLib( const LIB_ID& aLibId, int aUn
}
SelectActiveLibrary( aLibId.GetLibNickname() );
- return LoadComponentFromCurrentLib( aLibId.GetLibItemName(), aUnit, aConvert );
+ return LoadSymbolFromCurrentLib( aLibId.GetLibItemName(), aUnit, aConvert );
}
-bool SYMBOL_EDIT_FRAME::LoadComponentFromCurrentLib( const wxString& aAliasName, int aUnit,
- int aConvert )
+bool SYMBOL_EDIT_FRAME::LoadSymbolFromCurrentLib( const wxString& aAliasName, int aUnit,
+ int aConvert )
{
LIB_PART* alias = nullptr;
@@ -264,7 +264,7 @@ bool SYMBOL_EDIT_FRAME::LoadOneLibraryPartAux( LIB_PART* aEntry, const wxString&
// Display the document information based on the entry selected just in
// case the entry is an alias.
- DisplayCmpDoc();
+ DisplaySymbolDatasheet();
Refresh();
return true;
@@ -750,7 +750,7 @@ void SYMBOL_EDIT_FRAME::UpdateAfterSymbolProperties( wxString* aOldName )
RebuildSymbolUnitsList();
SetShowDeMorgan( GetCurPart()->Flatten()->HasConversion() );
updateTitle();
- DisplayCmpDoc();
+ DisplaySymbolDatasheet();
RebuildView();
OnModify();
@@ -1136,7 +1136,7 @@ bool SYMBOL_EDIT_FRAME::saveAllLibraries( bool aRequireConfirmation )
}
-void SYMBOL_EDIT_FRAME::DisplayCmpDoc()
+void SYMBOL_EDIT_FRAME::DisplaySymbolDatasheet()
{
EDA_DRAW_FRAME::ClearMsgPanel();
diff --git a/eeschema/symbol_editor/symbol_editor_plotter.cpp b/eeschema/symbol_editor/symbol_editor_plotter.cpp
index eae7d38435..a0b7087ed7 100644
--- a/eeschema/symbol_editor/symbol_editor_plotter.cpp
+++ b/eeschema/symbol_editor/symbol_editor_plotter.cpp
@@ -29,7 +29,7 @@
#include
#include
-void SYMBOL_EDIT_FRAME::SVG_PlotComponent( const wxString& aFullFileName )
+void SYMBOL_EDIT_FRAME::SVGPlotSymbol( const wxString& aFullFileName )
{
KIGFX::SCH_RENDER_SETTINGS renderSettings;
renderSettings.LoadColors( GetColorSettings() );
diff --git a/eeschema/symbol_editor/symbol_editor_undo_redo.cpp b/eeschema/symbol_editor/symbol_editor_undo_redo.cpp
index 2211d3f013..eec7a3b22c 100644
--- a/eeschema/symbol_editor/symbol_editor_undo_redo.cpp
+++ b/eeschema/symbol_editor/symbol_editor_undo_redo.cpp
@@ -57,7 +57,7 @@ void SYMBOL_EDIT_FRAME::SaveCopyInUndoList( EDA_ITEM* aItem, UNDO_REDO aUndoType
}
-void SYMBOL_EDIT_FRAME::GetComponentFromRedoList()
+void SYMBOL_EDIT_FRAME::GetSymbolFromRedoList()
{
if( GetRedoCommandCount() <= 0 )
return;
@@ -105,7 +105,7 @@ void SYMBOL_EDIT_FRAME::GetComponentFromRedoList()
}
-void SYMBOL_EDIT_FRAME::GetComponentFromUndoList()
+void SYMBOL_EDIT_FRAME::GetSymbolFromUndoList()
{
if( GetUndoCommandCount() <= 0 )
return;
@@ -153,7 +153,7 @@ void SYMBOL_EDIT_FRAME::GetComponentFromUndoList()
}
-void SYMBOL_EDIT_FRAME::RollbackPartFromUndo()
+void SYMBOL_EDIT_FRAME::RollbackSymbolFromUndo()
{
m_toolManager->RunAction( EE_ACTIONS::clearSelection, true );
diff --git a/eeschema/tools/assign_footprints.cpp b/eeschema/tools/assign_footprints.cpp
index 6ed854601f..7b828640b9 100644
--- a/eeschema/tools/assign_footprints.cpp
+++ b/eeschema/tools/assign_footprints.cpp
@@ -46,7 +46,7 @@ void SCH_EDITOR_CONTROL::AssignFootprints( const std::string& aChangedSetOfRefer
SCH_SHEET_LIST sheets = m_frame->Schematic().GetSheets();
bool isChanged = false;
- sheets.GetComponents( refs, false );
+ sheets.GetSymbols( refs, false );
DSNLEXER lexer( aChangedSetOfReferences, FROM_UTF8( __func__ ) );
PTREE doc;
@@ -81,7 +81,7 @@ void SCH_EDITOR_CONTROL::AssignFootprints( const std::string& aChangedSetOfRefer
// We have found a candidate.
// Note: it can be not unique (multiple parts per package)
// So we *do not* stop the search here
- SCH_COMPONENT* component = refs[ii].GetComp();
+ SCH_COMPONENT* component = refs[ ii ].GetSymbol();
// For backwards-compatibility CvPcb currently updates all instances of a
// component (even though it lists these instances separately).
SCH_SHEET_PATH* sheetPath = nullptr; // &refs[ii].GetSheetPath();
@@ -122,7 +122,7 @@ bool SCH_EDITOR_CONTROL::processCmpToFootprintLinkFile( const wxString& aFullFil
SCH_REFERENCE_LIST referencesList;
SCH_SHEET_LIST sheetList = m_frame->Schematic().GetSheets();
- sheetList.GetComponents( referencesList, false );
+ sheetList.GetSymbols( referencesList, false );
FILE* cmpFile = wxFopen( aFullFilename, wxT( "rt" ) );
@@ -182,13 +182,13 @@ bool SCH_EDITOR_CONTROL::processCmpToFootprintLinkFile( const wxString& aFullFil
// We have found a candidate.
// Note: it can be not unique (multiple units per part)
// So we *do not* stop the search here
- SCH_COMPONENT* component = referencesList[ii].GetComp();
+ SCH_COMPONENT* symbol = referencesList[ ii ].GetSymbol();
SCH_SHEET_PATH* sheetPath = &referencesList[ii].GetSheetPath();
- component->SetFootprint( sheetPath, footprint );
+ symbol->SetFootprint( sheetPath, footprint );
if( aForceVisibilityState )
- component->GetField( FOOTPRINT_FIELD )->SetVisible( aVisibilityState );
+ symbol->GetField( FOOTPRINT_FIELD )->SetVisible( aVisibilityState );
}
}
}
diff --git a/eeschema/tools/backannotate.cpp b/eeschema/tools/backannotate.cpp
index c5ecda58b7..508d598aca 100644
--- a/eeschema/tools/backannotate.cpp
+++ b/eeschema/tools/backannotate.cpp
@@ -74,8 +74,8 @@ bool BACK_ANNOTATE::BackAnnotateSymbols( const std::string& aNetlist )
getPcbModulesFromString( aNetlist );
SCH_SHEET_LIST sheets = m_frame->Schematic().GetSheets();
- sheets.GetComponents( m_refs, false );
- sheets.GetMultiUnitComponents( m_multiUnitsRefs );
+ sheets.GetSymbols( m_refs, false );
+ sheets.GetMultiUnitSymbols( m_multiUnitsRefs );
getChangeList();
checkForUnusedSymbols();
@@ -230,7 +230,7 @@ void BACK_ANNOTATE::getChangeList()
for( size_t i = 0; i < refList.GetCount(); ++i )
{
- refList[i].GetComp()->ClearFlags( SKIP_STRUCT );
+ refList[ i ].GetSymbol()->ClearFlags(SKIP_STRUCT );
m_changelist.emplace_back( CHANGELIST_ITEM( refList[i], pcbData ) );
}
@@ -248,7 +248,7 @@ void BACK_ANNOTATE::getChangeList()
if( refIndex >= 0 )
{
- m_refs[refIndex].GetComp()->ClearFlags( SKIP_STRUCT );
+ m_refs[ refIndex ].GetSymbol()->ClearFlags(SKIP_STRUCT );
m_changelist.emplace_back( CHANGELIST_ITEM( m_refs[refIndex], pcbData ) );
}
else
@@ -304,13 +304,13 @@ void BACK_ANNOTATE::applyChangelist()
// Apply changes from change list
for( CHANGELIST_ITEM& item : m_changelist )
{
- SCH_REFERENCE& ref = item.first;
- PCB_FP_DATA& fpData = *item.second;
- SCH_COMPONENT* comp = ref.GetComp();
- SCH_SCREEN* screen = ref.GetSheetPath().LastScreen();
- wxString oldFootprint = ref.GetFootprint();
- wxString oldValue = ref.GetValue();
- bool skip = ( ref.GetComp()->GetFlags() & SKIP_STRUCT ) > 0;
+ SCH_REFERENCE& ref = item.first;
+ PCB_FP_DATA& fpData = *item.second;
+ SCH_COMPONENT* symbol = ref.GetSymbol();
+ SCH_SCREEN* screen = ref.GetSheetPath().LastScreen();
+ wxString oldFootprint = ref.GetFootprint();
+ wxString oldValue = ref.GetValue();
+ bool skip = ( ref.GetSymbol()->GetFlags() & SKIP_STRUCT ) > 0;
if( m_processReferences && ref.GetRef() != fpData.m_ref && !skip )
{
@@ -321,9 +321,9 @@ void BACK_ANNOTATE::applyChangelist()
if( !m_dryRun )
{
- m_frame->SaveCopyInUndoList( screen, comp, UNDO_REDO::CHANGED, m_appendUndo );
+ m_frame->SaveCopyInUndoList( screen, symbol, UNDO_REDO::CHANGED, m_appendUndo );
m_appendUndo = true;
- comp->SetRef( &ref.GetSheetPath(), fpData.m_ref );
+ symbol->SetRef( &ref.GetSheetPath(), fpData.m_ref );
}
m_reporter.ReportHead( msg, RPT_SEVERITY_ACTION );
@@ -339,9 +339,9 @@ void BACK_ANNOTATE::applyChangelist()
if( !m_dryRun )
{
- m_frame->SaveCopyInUndoList( screen, comp, UNDO_REDO::CHANGED, m_appendUndo );
+ m_frame->SaveCopyInUndoList( screen, symbol, UNDO_REDO::CHANGED, m_appendUndo );
m_appendUndo = true;
- comp->SetFootprint( &ref.GetSheetPath(), fpData.m_footprint );
+ symbol->SetFootprint( &ref.GetSheetPath(), fpData.m_footprint );
}
m_reporter.ReportHead( msg, RPT_SEVERITY_ACTION );
@@ -357,9 +357,9 @@ void BACK_ANNOTATE::applyChangelist()
if( !m_dryRun )
{
- m_frame->SaveCopyInUndoList( screen, comp, UNDO_REDO::CHANGED, m_appendUndo );
+ m_frame->SaveCopyInUndoList( screen, symbol, UNDO_REDO::CHANGED, m_appendUndo );
m_appendUndo = true;
- comp->SetValue( &ref.GetSheetPath(), fpData.m_value );
+ symbol->SetValue( &ref.GetSheetPath(), fpData.m_value );
}
m_reporter.ReportHead( msg, RPT_SEVERITY_ACTION );
@@ -371,7 +371,7 @@ void BACK_ANNOTATE::applyChangelist()
{
const wxString& pinNumber = entry.first;
const wxString& shortNetName = entry.second;
- SCH_PIN* pin = comp->GetPin( pinNumber );
+ SCH_PIN* pin = symbol->GetPin( pinNumber );
if( !pin )
{
@@ -421,7 +421,7 @@ static LABEL_SPIN_STYLE orientLabel( SCH_PIN* aPin )
case PIN_RIGHT: spin = LABEL_SPIN_STYLE::LEFT; break;
}
- // Reorient based on the actual component orientation now
+ // Reorient based on the actual symbol orientation now
struct ORIENT
{
int flag;
@@ -447,16 +447,16 @@ static LABEL_SPIN_STYLE orientLabel( SCH_PIN* aPin )
ORIENT o = orientations[ 0 ];
- SCH_COMPONENT* comp = aPin->GetParentSymbol();
+ SCH_COMPONENT* parentSymbol = aPin->GetParentSymbol();
- if( !comp )
+ if( !parentSymbol )
return spin;
- int compOrient = comp->GetOrientation();
+ int symbolOrientation = parentSymbol->GetOrientation();
for( auto& i : orientations )
{
- if( i.flag == compOrient )
+ if( i.flag == symbolOrientation )
{
o = i;
break;
diff --git a/eeschema/tools/ee_point_editor.cpp b/eeschema/tools/ee_point_editor.cpp
index 3df446b6de..07b403667d 100644
--- a/eeschema/tools/ee_point_editor.cpp
+++ b/eeschema/tools/ee_point_editor.cpp
@@ -899,7 +899,7 @@ void EE_POINT_EDITOR::saveItemsToUndo()
void EE_POINT_EDITOR::rollbackFromUndo()
{
if( m_isSymbolEditor )
- static_cast( m_frame )->RollbackPartFromUndo();
+ static_cast( m_frame )->RollbackSymbolFromUndo();
else
static_cast( m_frame )->RollbackSchematicFromUndo();
}
diff --git a/eeschema/tools/lib_control.cpp b/eeschema/tools/lib_control.cpp
index 1120462ebe..e879d58425 100644
--- a/eeschema/tools/lib_control.cpp
+++ b/eeschema/tools/lib_control.cpp
@@ -379,7 +379,7 @@ int LIB_CONTROL::ExportSymbolAsSVG( const TOOL_EVENT& aEvent )
pageTemp.SetHeightMils( int( componentSize.y * 1.2 ) );
editFrame->GetScreen()->SetPageSettings( pageTemp );
- editFrame->SVG_PlotComponent( fullFileName );
+ editFrame->SVGPlotSymbol( fullFileName );
editFrame->GetScreen()->SetPageSettings( pageSave );
}
diff --git a/eeschema/tools/lib_edit_tool.cpp b/eeschema/tools/lib_edit_tool.cpp
index aff86f57c0..e3922ab416 100644
--- a/eeschema/tools/lib_edit_tool.cpp
+++ b/eeschema/tools/lib_edit_tool.cpp
@@ -527,7 +527,7 @@ void LIB_EDIT_TOOL::editFieldProperties( LIB_FIELD* aField )
updateItem( aField, true );
m_frame->GetCanvas()->Refresh();
m_frame->OnModify();
- m_frame->DisplayCmpDoc();
+ m_frame->DisplaySymbolDatasheet();
}
}
@@ -594,7 +594,7 @@ int LIB_EDIT_TOOL::PinTable( const TOOL_EVENT& aEvent )
int LIB_EDIT_TOOL::Undo( const TOOL_EVENT& aEvent )
{
- m_frame->GetComponentFromUndoList();
+ m_frame->GetSymbolFromUndoList();
EE_SELECTION_TOOL* selTool = m_toolMgr->GetTool();
selTool->RebuildSelection();
@@ -605,7 +605,7 @@ int LIB_EDIT_TOOL::Undo( const TOOL_EVENT& aEvent )
int LIB_EDIT_TOOL::Redo( const TOOL_EVENT& aEvent )
{
- m_frame->GetComponentFromRedoList();
+ m_frame->GetSymbolFromRedoList();
EE_SELECTION_TOOL* selTool = m_toolMgr->GetTool();
selTool->RebuildSelection();
diff --git a/eeschema/tools/lib_move_tool.cpp b/eeschema/tools/lib_move_tool.cpp
index 49fa9cfa2d..0cff0e1e7c 100644
--- a/eeschema/tools/lib_move_tool.cpp
+++ b/eeschema/tools/lib_move_tool.cpp
@@ -286,7 +286,7 @@ int LIB_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
if( restore_state )
{
- m_frame->RollbackPartFromUndo();
+ m_frame->RollbackSymbolFromUndo();
if( unselect )
m_toolMgr->RunAction( EE_ACTIONS::clearSelection, true );
diff --git a/eeschema/tools/sch_edit_tool.cpp b/eeschema/tools/sch_edit_tool.cpp
index 1b8e12be63..e89859aee2 100644
--- a/eeschema/tools/sch_edit_tool.cpp
+++ b/eeschema/tools/sch_edit_tool.cpp
@@ -1422,8 +1422,8 @@ int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
{
auto editor = (SYMBOL_EDIT_FRAME*) m_frame->Kiway().Player( FRAME_SCH_SYMBOL_EDITOR, true );
- editor->LoadComponentAndSelectLib( component->GetLibId(), component->GetUnit(),
- component->GetConvert() );
+ editor->LoadSymbolAndSelectLib( component->GetLibId(), component->GetUnit(),
+ component->GetConvert());
editor->Show( true );
editor->Raise();
diff --git a/eeschema/tools/sch_editor_control.cpp b/eeschema/tools/sch_editor_control.cpp
index 91e7c8afbd..66c44e8ff7 100644
--- a/eeschema/tools/sch_editor_control.cpp
+++ b/eeschema/tools/sch_editor_control.cpp
@@ -1246,7 +1246,7 @@ bool SCH_EDITOR_CONTROL::doCopy()
}
m_supplementaryClipboardInstances.Clear();
- schematic.GetSheets().GetComponents( m_supplementaryClipboardInstances, true, true );
+ schematic.GetSheets().GetSymbols( m_supplementaryClipboardInstances, true, true );
m_supplementaryClipboardPath = m_frame->GetCurrentSheet().Path();
STRING_FORMATTER formatter;
diff --git a/eeschema/symbol_editor/symbol_edit_frame.h b/eeschema/symbol_editor/symbol_edit_frame.h
index f4073b1f76..c67f8e9e54 100644
--- a/eeschema/symbol_editor/symbol_edit_frame.h
+++ b/eeschema/symbol_editor/symbol_edit_frame.h
@@ -76,8 +76,8 @@ class SYMBOL_EDIT_FRAME : public SCH_BASE_FRAME
wxString m_reference;
// True to force DeMorgan/normal tools selection enabled.
// They are enabled when the loaded component has graphic items for converted shape
// But under some circumstances (New component created) these tools must left enabled
static bool m_showDeMorgan;
public:
@@ -267,7 +267,10 @@ public:
bool GetShowDeMorgan() const { return m_showDeMorgan; }
void SetShowDeMorgan( bool show ) { m_showDeMorgan = show; }
- void ClearMsgPanel() override { DisplayCmpDoc(); }
+ void ClearMsgPanel() override
+ {
+ DisplaySymbolDatasheet();
+ }
bool IsSymbolFromSchematic() const { return m_isSymbolFromSchematic; }
@@ -324,7 +327,7 @@ private:
* @param aConvert Convert to be selected
* @return true if the symbol loaded correctly.
*/
- bool LoadComponentFromCurrentLib( const wxString& aAliasName, int aUnit = 0, int aConvert = 0 );
+ bool LoadSymbolFromCurrentLib( const wxString& aAliasName, int aUnit = 0, int aConvert = 0 );
/**
* Create a copy of \a aLibEntry into memory.
@@ -341,24 +344,24 @@ private:
public:
/**
* Display the documentation of the selected component.
*/
- void DisplayCmpDoc();
+ void DisplaySymbolDatasheet();
// General editing
/**
* Create a copy of the current component, and save it in the undo list.
*
* Because a component in library editor does not have a lot of primitives,
* the full data is duplicated. It is not worth to try to optimize this save function.
*/
void SaveCopyInUndoList( EDA_ITEM* aItem, UNDO_REDO aUndoType = UNDO_REDO::LIBEDIT,
bool aAppend = false );
- void GetComponentFromUndoList();
- void GetComponentFromRedoList();
+ void GetSymbolFromUndoList();
+ void GetSymbolFromRedoList();
- void RollbackPartFromUndo();
+ void RollbackSymbolFromUndo();
/**
* Free the undo or redo list from \a aList element.
@@ -376,7 +379,7 @@ public:
private:
/**
- * Read a component symbol file (*.sym ) and add graphic items to the current component.
+ * Read a symbol file (*.sym ) and add graphic items to the current symbol.
*
* A symbol file *.sym has the same format as a library, and contains only one symbol.
*/
@@ -385,7 +388,7 @@ private:
/**
* Saves the current symbol to a symbol file.
*
- * The symbol file format is similar to the standard component library file format, but
+ * The symbol file format is similar to the standard symbol library file format, but
* there is only one symbol. Invisible pins are not saved.
*/
void SaveOneSymbol();
@@ -401,7 +404,7 @@ public:
* @param aConvert the DeMorgan variant to show
* @return true if the symbol defined by \a aLibId was loaded.
*/
- bool LoadComponentAndSelectLib( const LIB_ID& aLibId, int aUnit, int aConvert );
+ bool LoadSymbolAndSelectLib( const LIB_ID& aLibId, int aUnit, int aConvert );
/**
* Print a page
@@ -411,9 +414,9 @@ public:
void PrintPage( RENDER_SETTINGS* aSettings ) override;
/**
* Creates the SVG print file for the current edited component.
*/
- void SVG_PlotComponent( const wxString& aFullFileName );
+ void SVGPlotSymbol( const wxString& aFullFileName );
/**
* Synchronize the library manager to the symbol library table, and then the symbol tree
@@ -461,7 +464,7 @@ public:
* @param aConvert the alternate body style of the symbol to edit.
*/
void LoadSymbolFromSchematic( const std::unique_ptr& aSymbol,
- const wxString& aReference, int aUnit, int aConvert );
+ const wxString& aReference, int aUnit, int aConvert );
///> Restores the empty editor screen, without any part or library selected.
void emptyScreen();
@@ -483,16 +486,17 @@ private:
///> Returns currently edited part.
LIB_PART* getTargetPart() const;
///> Returns either the part selected in the component tree, if context menu is active
///> or the currently modified part.
LIB_ID getTargetLibId() const;
///> Returns either the library selected in the component tree, if context menu is active
///> or the library that is currently modified.
wxString getTargetLib() const;
- /* Returns true when the operation has succeeded (all requested libraries have been saved or
- * none was selected and confirmed by OK).
+ /*
+ * Returns true when the operation has succeeded (all requested libraries have been saved
+ * or none was selected and confirmed by OK).
* @param aRequireConfirmation when true, the user must be asked to confirm.
*/
bool saveAllLibraries( bool aRequireConfirmation );
@@ -506,7 +510,7 @@ private:
///> Returns true if \a aLibId is an alias for the editor screen part.
bool isCurrentPart( const LIB_ID& aLibId ) const;
///> Renames LIB_PART aliases to avoid conflicts before adding a component to a library
void ensureUniqueName( LIB_PART* aPart, const wxString& aLibrary );
DECLARE_EVENT_TABLE()
@@ -76,8 +76,8 @@ class SYMBOL_EDIT_FRAME : public SCH_BASE_FRAME
wxString m_reference;
// True to force DeMorgan/normal tools selection enabled.
- // They are enabled when the loaded component has graphic items for converted shape
- // But under some circumstances (New component created) these tools must left enabled
+ // They are enabled when the loaded symbol has graphic items for converted shape
+ // But under some circumstances (New symbol created) these tools must left enabled
static bool m_showDeMorgan;
public:
@@ -341,24 +344,24 @@ private:
public:
/**
- * Display the documentation of the selected component.
+ * Display the documentation of the selected symbol.
*/
@@ -341,24 +344,24 @@ private:
// General editing
/**
- * Create a copy of the current component, and save it in the undo list.
+ * Create a copy of the current symbol, and save it in the undo list.
*
@@ -341,24 +344,24 @@ private:
*
- * Because a component in library editor does not have a lot of primitives,
- * the full data is duplicated. It is not worth to try to optimize this save function.
+ * Because a symbol in library editor does not have a lot of primitives, the full data is
+ * duplicated. It is not worth to try to optimize this save function.
*/
void SaveCopyInUndoList( EDA_ITEM* aItem, UNDO_REDO aUndoType = UNDO_REDO::LIBEDIT,
@@ -411,9 +414,9 @@ public:
void PrintPage( RENDER_SETTINGS* aSettings ) override;
/**
- * Creates the SVG print file for the current edited component.
+ * Creates the SVG print file for the current edited symbol.
*/
@@ -483,16 +486,17 @@ private:
///> Returns currently edited part.
LIB_PART* getTargetPart() const;
- ///> Returns either the part selected in the component tree, if context menu is active
- ///> or the currently modified part.
+ ///> Returns either the part selected in the symbol tree, if context menu is active or the
+ ///> currently modified part.
LIB_ID getTargetLibId() const;
@@ -483,16 +486,17 @@ private:
LIB_ID getTargetLibId() const;
- ///> Returns either the library selected in the component tree, if context menu is active
- ///> or the library that is currently modified.
+ ///> Returns either the library selected in the symbol tree, if context menu is active or
+ ///> the library that is currently modified.
wxString getTargetLib() const;
@@ -506,7 +510,7 @@ private:
///> Returns true if \a aLibId is an alias for the editor screen part.
bool isCurrentPart( const LIB_ID& aLibId ) const;
- ///> Renames LIB_PART aliases to avoid conflicts before adding a component to a library
+ ///> Renames LIB_PART aliases to avoid conflicts before adding a symbol to a library
void ensureUniqueName( LIB_PART* aPart, const wxString& aLibrary );
DECLARE_EVENT_TABLE()